Index: lib/prefs.js
===================================================================
--- a/lib/prefs.js
+++ b/lib/prefs.js
@@ -155,7 +155,7 @@
 /**
  * Whether to show tracking warning in options page when both
  * Acceptable Ads and subscription of type "Privacy" are enabled.
- * 
+ *
  * @type {boolean}
  */
 defaults.ui_warn_tracking = true;
@@ -183,7 +183,7 @@
 defaults.show_devtools_panel = true;
 
 /**
  * Whether to suppress the first run page. This preference isn't
  * set by the extension but can be pre-configured externally.
  *
  * @see https://adblockplus.org/development-builds/suppressing-the-first-run-page-on-chrome
@@ -201,6 +201,14 @@
 defaults.additional_subscriptions = [];
 
 /**
+ * The version of major updates that the user is aware of. If it's too low,
+ * the updates page will be shown to inform the user about intermediate changes.
+ *
+ * @type {number}
+ */
+defaults.last_updates_page_displayed = 0;
+
+/**
   * @namespace
   * @static
   */
@@ -183,7 +183,7 @@
 
 /**
- * Whether to suppress the first run page. This preference isn't
+ * Whether to suppress the first run and updates page. This preference isn't
  * set by the extension but can be pre-configured externally.
  *
